summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorChristopher Tate <ctate@google.com>2015-03-05 18:31:38 -0800
committerChristopher Tate <ctate@google.com>2015-03-05 18:31:38 -0800
commita8a739f34c4d9c56b113810582801f36381cbc77 (patch)
tree91647480eba661a555134968c12fdb908cf15670
parente51f79975e829d8f4afc77d0e98bad0f5fde73d2 (diff)
downloadframeworks_base-a8a739f34c4d9c56b113810582801f36381cbc77.zip
frameworks_base-a8a739f34c4d9c56b113810582801f36381cbc77.tar.gz
frameworks_base-a8a739f34c4d9c56b113810582801f36381cbc77.tar.bz2
Don't back up / restore the code_cache/ directory
Bug 19628750 Change-Id: I1f2f5e8083675bf70d17c0c143dc813ca9e04610
-rw-r--r--core/java/android/app/backup/BackupAgent.java11
1 files changed, 9 insertions, 2 deletions
diff --git a/core/java/android/app/backup/BackupAgent.java b/core/java/android/app/backup/BackupAgent.java
index 1b1e600..7f89100 100644
--- a/core/java/android/app/backup/BackupAgent.java
+++ b/core/java/android/app/backup/BackupAgent.java
@@ -258,6 +258,7 @@ public abstract class BackupAgent extends ContextWrapper {
*
* <ul>
* <li>The contents of the {@link #getCacheDir()} directory</li>
+ * <li>The contents of the {@link #getCodeCacheDir()} directory</li>
* <li>The contents of the {@link #getNoBackupFilesDir()} directory</li>
* <li>The contents of the app's shared library directory</li>
* </ul>
@@ -285,6 +286,7 @@ public abstract class BackupAgent extends ContextWrapper {
String databaseDir = getDatabasePath("foo").getParentFile().getCanonicalPath();
String sharedPrefsDir = getSharedPrefsFile("foo").getParentFile().getCanonicalPath();
String cacheDir = getCacheDir().getCanonicalPath();
+ String codeCacheDir = getCodeCacheDir().getCanonicalPath();
String libDir = (appInfo.nativeLibraryDir != null)
? new File(appInfo.nativeLibraryDir).getCanonicalPath()
: null;
@@ -298,6 +300,7 @@ public abstract class BackupAgent extends ContextWrapper {
filterSet.add(libDir);
}
filterSet.add(cacheDir);
+ filterSet.add(codeCacheDir);
filterSet.add(databaseDir);
filterSet.add(sharedPrefsDir);
filterSet.add(filesDir);
@@ -354,6 +357,7 @@ public abstract class BackupAgent extends ContextWrapper {
String dbDir;
String spDir;
String cacheDir;
+ String codeCacheDir;
String libDir;
String efDir = null;
String filePath;
@@ -367,6 +371,7 @@ public abstract class BackupAgent extends ContextWrapper {
dbDir = getDatabasePath("foo").getParentFile().getCanonicalPath();
spDir = getSharedPrefsFile("foo").getParentFile().getCanonicalPath();
cacheDir = getCacheDir().getCanonicalPath();
+ codeCacheDir = getCodeCacheDir().getCanonicalPath();
libDir = (appInfo.nativeLibraryDir == null)
? null
: new File(appInfo.nativeLibraryDir).getCanonicalPath();
@@ -380,7 +385,8 @@ public abstract class BackupAgent extends ContextWrapper {
}
// Now figure out which well-defined tree the file is placed in, working from
// most to least specific. We also specifically exclude the lib and cache dirs.
filePath = file.getCanonicalPath();
} catch (IOException e) {
Log.w(TAG, "Unable to obtain canonical paths");
@@ -388,9 +394,10 @@ public abstract class BackupAgent extends ContextWrapper {
}
if (filePath.startsWith(cacheDir)
+ || filePath.startsWith(codeCacheDir)
|| filePath.startsWith(libDir)
|| filePath.startsWith(nbFilesDir)) {
- Log.w(TAG, "lib, cache, and no_backup files are not backed up");
+ Log.w(TAG, "lib, cache, code_cache, and no_backup files are not backed up");
return;
}
@@ -380,7 +385,8 @@ public abstract class BackupAgent extends ContextWrapper {
}
// Now figure out which well-defined tree the file is placed in, working from
- // most to least specific. We also specifically exclude the lib and cache dirs.
+ // most to least specific. We also specifically exclude the lib, cache,
+ // and code_cache dirs.
filePath = file.getCanonicalPath();
} catch (IOException e) {